//////////////////////////////////////////////////////////////////////////////////
//
// Program Call example
//
//////////////////////////////////////////////////////////////////////////////////
//
// This source is an example of IBM Toolbox for Java "ProgramCall".
// IBM grants you a nonexclusive license to use this as an example
// from which you can generate similar function tailored to
// your own specific needs.
//
// This sample code is provided by IBM for illustrative purposes
// only. These examples have not been thoroughly tested under all
// conditions. IBM, therefore, cannot guarantee or imply
// reliability, serviceability, or function of these programs.
//
// All programs contained herein are provided to you "AS IS"
// without any warranties of any kind.  The implied warranties of
// merchantablility and fitness for a particular purpose are
// expressly disclaimed.
//
// IBM Toolbox for Java
// (C) Copyright IBM Corp. 1998, 1998
// All rights reserved.
// US Government Users Restricted Rights -
// Use, duplication, or disclosure restricted
// by GSA ADP Schedule Contract with IBM Corp.
//
//////////////////////////////////////////////////////////////////////////////////


import com.ibm.as400.access.*;


 //
 // This program calls i5/OS API QSYRUSRI (Retrieve User Information)
 // to get information on the current user.
 //

 public class qsyrusri2
 {
     public static void main(String[] argv)
     {
         try
         {
             String msgId, msgText;

             AS400 system = new AS400();

             // Create a binary converter to go between an i5/OS
             // bin 4 and a Java int.
             AS400Bin4 bin4   = new AS400Bin4();

             // Create text converters for the various sizes
             // of strings will use.
             AS400Text char6  = new AS400Text(6,  system.getCcsid(), system);
             AS400Text char7  = new AS400Text(7,  system.getCcsid(), system);
             AS400Text char8  = new AS400Text(8,  system.getCcsid(), system);
      // ---------------------------------------------------------------
      //             Intro Lab Exercise #4 Part #1 - Insert code here.
      // ---------------------------------------------------------------
             AS400Text char10 = new AS400Text(10, system.getCcsid(), system);
      // ---------------------------------------------------------------
      //                           End of code.
      // ---------------------------------------------------------------

             // Reroute system.error to system.out
             System.setErr(System.out);

             // Create a program call object.  Then
             // set the program name to "/QSYS.LIB/QSYRUSRI.PGM"
      // ---------------------------------------------------------------
      //             Intro Lab Exercise #4 Part #2 - Insert code here.
      // ---------------------------------------------------------------
             ProgramCall pc = new ProgramCall(system);
             pc.setProgram("/QSYS.LIB/QSYRUSRI.PGM");
      // ---------------------------------------------------------------
      //                           End of code.
      // ---------------------------------------------------------------

             // The program has five parameters.
             ProgramParameter[] parms = new ProgramParameter[5];

             // First parm is the output area that contains the result.
             // The parameter value 100 means expect 100 bytes back.
             parms[0] = new ProgramParameter(100);

             // Second parm is the size of the output area
             // (100 bytes in our case).
             parms[1] = new ProgramParameter(bin4.toBytes(100));

      // ---------------------------------------------------------------
      //             Intro Lab Exercise #4 Part #3 - Insert code here.
      // ---------------------------------------------------------------
             // Third parm is the output format to use.  The
             // server expects the format to be in EBCDIC so we
             // use our character converter to convert from a Java
             // Unicode string to a byte array containing EBCDIC bytes.
             parms[2] = new ProgramParameter(char8.toBytes("USRI0100"));
      // ---------------------------------------------------------------
      //                           End of code.
      // ---------------------------------------------------------------

             // Fourth parm is the user profile.  It is also converted
             // from Unicode to EBCDIC.
             parms[3] = new ProgramParameter(char10.toBytes("*CURRENT"));

             // Fifth parm is the 32 byte error area.
             byte[] errorArea = new byte[32];
             parms[4] = new ProgramParameter(errorArea, 32);

             System.out.println("Beginning ProgramCall Example..");
             System.out.println("    Setting input parameters...");

             // Give the list of parameters to the program call object.
             pc.setParameterList(parms);

             // Call the program.  If the return code is false,
             // we received messages from the server saying why the
             // program failed.  For example, program not found,
             // not authorized to program, etc.  The failure to connect
             // to the server will show up as an exception, not a message.
             if (pc.run() == false)
             {
                 // Retrieve list of i5/OS messages
                 AS400Message[] msgs = pc.getMessageList();

                 // Iterate through messages and write them to standard output
                 for (int m = 0; m < msgs.length; m++)
                 {
                     msgId = msgs[m].getID();
                     msgText = msgs[m].getText();
                     System.out.println("    " + msgId + " - " + msgText);
                 }
                 System.out.println("** Call to QSYRUSRI failed. See messages above **");
             }
             // else we were able to call the program and received data.
             else
             {
                 // Pull the data out of the output parm (the first parameter)
                 byte[] data = parms[0].getOutputData();

                 // Print various values out of the return data.  Note
                 // the programmer has to know where in the buffer the
                 // data starts.  Also note the data at this point is
                 // binary / Ebcdic.  To be used by Java it must be
                 // converted to Java types (int, long, ...) and Java
                 // Strings.
                 int value   = ((Integer) bin4.toObject(data)).intValue();
                 System.out.println("        Bytes returned:      " + value);

                 value   = ((Integer) bin4.toObject(data, 4)).intValue();
                 System.out.println("        Bytes available:     " + value);

      // ---------------------------------------------------------------
      //             Intro Lab Exercise #4 Part #4 - Insert code here.
      // ---------------------------------------------------------------
                 String strValue = (String) char10.toObject(data, 8);
      // ---------------------------------------------------------------
      //                           End of code.
      // ---------------------------------------------------------------
                 System.out.println("        Profile name:        " + strValue);

                 strValue = (String) char7.toObject(data, 18);
                 System.out.println("        Previous signon date:" + strValue);

                 strValue = (String) char6.toObject(data, 25);
                 System.out.println("        Previous signon time:" + strValue);
             }
         }
         catch (Exception e)
         {
             System.out.println("Unexpected Exception ");
             e.printStackTrace();
             System.out.println("*** Call to QSYRUSRI failed. ***");
         }

         System.exit(0);
     }
 }

